#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['gidconfig',
 'gidconfig.data',
 'gidconfig.experimental',
 'gidconfig.standard',
 'gidconfig.utility']

package_data = \
{'': ['*']}

install_requires = \
['fuzzywuzzy==0.18.0', 'gidlogger>=0.1.33']

setup(name='gidconfig',
      version='0.2.7',
      description='Configuration provider package, that exposes the section as attribute and also automatically keeps the config file and object in sync.',
      author='Giddius',
      author_email=None,
      url='https://github.com/Giddius/Gidconfig',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
     )
