# region [Imports]

# * Gid Imports -->
import gidlogger as glog

# endregion [Imports]

# region [Logging]

log = glog.aux_library_logger(__name__)
log.info(glog.imported(__name__))

# endregion [Logging]


# region [Main_Exec]
if __name__ == '__main__':
    pass


# endregion [Main_Exec]
